@@ -27,3 +27,9 @@ let(
   }
 )
 
+## ------------------------------------------------------------------------
+a <- 1
+b <- 2
+let(c(z=quote(a)), z+b)
+eval(substitute(z+b, c(z=quote(a))))
+
